#[repr(transparent)]pub struct Subtag(TinyAsciiStr<8>);Expand description
A single item used in a list of Private extensions.
The subtag has to be an ASCII alphanumerical string no shorter than one character and no longer than eight.
Examples
use icu::locale::extensions::private::Subtag;
let subtag1: Subtag = "Foo".parse()
.expect("Failed to parse a Subtag.");
assert_eq!(subtag1.as_str(), "foo");Notice: This is different from the generic Subtag
which is between two and eight characters.
use icu::locale::extensions::private;
use icu::locale::subtags;
let subtag: Result<private::Subtag, _> = "f".parse();
assert!(subtag.is_ok());
let subtag: Result<subtags::Subtag, _> = "f".parse();
assert!(subtag.is_err());Tuple Fields
0: TinyAsciiStr<8>Implementations
Sourceimpl Subtag
impl Subtag
Sourcepub const fn try_from_str(s: &str) -> Result<Subtag, ParseError>
pub const fn try_from_str(s: &str) -> Result<Subtag, ParseError>
Sourcepub const fn try_from_utf8(code_units: &[u8]) -> Result<Subtag, ParseError>
pub const fn try_from_utf8(code_units: &[u8]) -> Result<Subtag, ParseError>
Sourcepub const fn try_from_raw(raw: [u8; 8]) -> Result<Subtag, ParseError>
pub const fn try_from_raw(raw: [u8; 8]) -> Result<Subtag, ParseError>
Safely creates a Subtag from its raw format
as returned by Self::into_raw. Unlike Self::try_from_utf8,
this constructor only takes normalized values.
Sourcepub const unsafe fn from_raw_unchecked(v: [u8; 8]) -> Subtag
pub const unsafe fn from_raw_unchecked(v: [u8; 8]) -> Subtag
Unsafely creates a Subtag from its raw format
as returned by Self::into_raw. Unlike Self::try_from_utf8,
this constructor only takes normalized values.
Safety
This function is safe iff Self::try_from_raw returns an Ok. This is the case
for inputs that are correctly normalized.
Sourcepub const fn into_raw(self) -> [u8; 8]
pub const fn into_raw(self) -> [u8; 8]
Deconstructs into a raw format to be consumed by
from_raw_unchecked or
try_from_raw.
Sourcepub fn strict_cmp(self, other: &[u8]) -> Ordering
pub fn strict_cmp(self, other: &[u8]) -> Ordering
Compare with BCP-47 bytes.
The return value is equivalent to what would happen if you first converted
self to a BCP-47 string and then performed a byte comparison.
This function is case-sensitive and results in a total order, so it is appropriate for
binary search. The only argument producing Ordering::Equal
is self.as_str().as_bytes().
Sourcepub fn normalizing_eq(self, other: &str) -> bool
pub fn normalizing_eq(self, other: &str) -> bool
Compare with a potentially unnormalized BCP-47 string.
The return value is equivalent to what would happen if you first parsed the BCP-47 string and then performed a structural comparison.